@@ -79,7 +79,7 @@ class Module:
         module_address: int,
         module_type: int,
         module_data: dict,
-        serial=None,
+        serial: str = "",
         memorymap=None,
         build_year=None,
         build_week=None,
@@ -91,7 +91,7 @@ class Module:
 
         self._name = {}
         self._sub_address = {}
-        self.serial = serial
+        self.serial: str = serial
         self.memory_map_version = memorymap
         self.build_year = build_year
         self.build_week = build_week
@@ -162,7 +162,7 @@ class Module:
     def get_type_name(self) -> str:
         return self._data["Type"]
 
-    def get_serial(self) -> str:
+    def get_serial(self) -> str | None:
         return self.serial
 
     def get_name(self) -> str:
@@ -375,7 +375,7 @@ class Module:
         # start the loading
         self._is_loading = True
         # load default channels
-        self.__load_default_channels()
+        await self.__load_default_channels()
         # load the data from memory ( the stuff that we need)
         await self.__load_memory()
         # load the module status
@@ -527,7 +527,7 @@ class Module:
                     msg.low_address = addr[1]
                     await self._writer(msg)
 
-    def __load_default_channels(self) -> None:
+    async def __load_default_channels(self) -> None:
         if "Channels" not in self._data:
             return
 
@@ -539,3 +539,8 @@ class Module:
             self._channels[int(chan)] = cls(
                 self, int(chan), chan_data["Name"], edit, self._writer, self._address
             )
+            if chan_data["Type"] == "Temperature":
+                if "Thermostat" in self._data or (
+                    "ThermostatAddr" in self._data and self._data["ThermostatAddr"] != 0
+                ):
+                    await self._channels[int(chan)].update({"thermostat": True})
